using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Txgy.RBS.DTO;
using Txgy.RBS.Framework.Api;
using Txgy.RBS.IServices;

namespace Txgy.RBS.IServices
{
    public interface IStationsService : IBaseService
    {
        ApiResult AddStations(StationDTO stationsDTO);

        ApiResult DeleteStations(int id);

        ApiResult UpdateStations(StationDTO stationsDTO);

        StationDTO GetStations(int id);
     
        List<StationDTO> GetAllStations();

        List<StationNumVpnDTO> GetStationNumVpn();

    }
}
